@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.29 2004/08/13 11:47:51 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.30 2004/09/13 00:05:10 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -1542,6 +1542,26 @@ static void process_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *b
 	status[i].desc = "if secondary does not respond in this milli seconds, abort the session";
 	i++;
 
+	status[i].name = "load_balance_mode";
+	snprintf(status[i].value, MAXVALLEN, "%d", pool_config.load_balance_mode);
+	status[i].desc = "non 0 if operating in load balancing mode";
+	i++;
+
+	status[i].name = "weight_master";
+	snprintf(status[i].value, MAXVALLEN, "%f", pool_config.weight_master);
+	status[i].desc = "weight of master";
+	i++;
+
+	status[i].name = "weight_secondary";
+	snprintf(status[i].value, MAXVALLEN, "%f", pool_config.weight_secondary);
+	status[i].desc = "weight of secondary";
+	i++;
+
+	status[i].name = "replication_stop_on_mismatch";
+	snprintf(status[i].value, MAXVALLEN, "%d", pool_config.replication_stop_on_mismatch);
+	status[i].desc = "stop replication mode on fatal error";
+	i++;
+
 	status[i].name = "current_backend_host_name";
 	snprintf(status[i].value, MAXVALLEN, "%s", pool_config.current_backend_host_name);
 	status[i].desc = "current master host name";
@@ -1557,16 +1577,6 @@ static void process_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *b
 	status[i].desc = "non 0 if actually operating in replication mode";
 	i++;
 
-	status[i].name = "load_balance_mode";
-	snprintf(status[i].value, MAXVALLEN, "%d", pool_config.load_balance_mode);
-	status[i].desc = "non 0 if operating in load balancing mode";
-	i++;
-
-	status[i].name = "replication_stop_on_mismatch";
-	snprintf(status[i].value, MAXVALLEN, "%d", pool_config.replication_stop_on_mismatch);
-	status[i].desc = "stop replication mode on fatal error";
-	i++;
-
 	nrows = i;
 
 	if (MAJOR(backend) == PROTO_MAJOR_V2)
@@ -1935,8 +1945,8 @@ static void start_load_balance(POOL_CONNECTION_POOL *backend)
 	/* temporary turn off replication mode */
 	REPLICATION = 0;
 
-	/* choose a master in random manner */
-	master = random() % backend->num;
+	/* choose a master in random manner with weight */
+	master = (random() <= weight_master)?0:1;
 	backend->slots[0] = slots[master];
 	pool_debug("start_load_balance: selected master is %d", master);
 
